@@ -839,6 +839,7 @@ json_parse_statement (JsonParser  *parser,
     case G_TOKEN_INT:
     case G_TOKEN_FLOAT:
     case G_TOKEN_STRING:
+      json_scanner_get_next_token (scanner);
       priv->root = priv->current_node = json_node_new (JSON_NODE_VALUE);
 
       if (token == G_TOKEN_INT)
@@ -1123,8 +1124,9 @@ json_parser_load_from_data (JsonParser   *parser,
  *
  * Retrieves the top level node from the parsed JSON stream.
  *
- * Return value: the root #JsonNode . The returned node is owned by
- *   the #JsonParser and should never be modified or freed.
+ * Return value: (transfer none): the root #JsonNode . The returned
+ *   node is owned by the #JsonParser and should never be modified
+ *   or freed.
  */
 JsonNode *
 json_parser_get_root (JsonParser *parser)
